SyncError enum
Synchronization error name.
Values
- authIncorrectCriticalVersion → const SyncError
-
Unsupported client version.
- syncIncorrectData → const SyncError
-
The transmitted data is incorrect.
- syncBlocked → const SyncError
-
Synchronization is blocked.
Another client is synchronizing.
- syncNotSaved → const SyncError
-
Error while saving data.
Internal error when saving on the server.
- syncEntityNotFound → const SyncError
-
The entity could not be found.
The creation event was not processed on the server this entity, so it can't update.
- syncFieldNotFound → const SyncError
-
Could not find the field.
An entity field update was sent that the server does not know about.
- syncEmptyFile → const SyncError
-
An empty file was transferred.
An attempt was made to load a file of zero size.
- syncInternalSyncError → const SyncError
-
Internal synchronization error on the server.
- syncTemporarilyImpossible → const SyncError
-
Synchronization is temporarily unavailable.
- updateEntityError → const SyncError
-
Error updating entities.
- downloadFilesError → const SyncError
-
Error downloading files.
- networkError → const SyncError
-
Network error.
- authError → const SyncError
-
Authorization error.
- temporaryServerError → const SyncError
-
Temporary server error.
- internalError → const SyncError
-
Internal error.
- updateLinksExeption → const SyncError
- updateLinksException → const SyncError
-
Error updating links.
- clientTimeout → const SyncError
-
Interrupted by client timeout.
- syncIsNotActive → const SyncError
-
Synchronization is not active.
Sync was disabled during or before the attempt.
- unknown → const SyncError
-
Unknown error.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited