SyncStateInfo class abstract

Synchronization status information, including errors.

Constructors

SyncStateInfo()

Properties

dataInfo SyncDataInfo
no setter
errorData Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
isFatalError bool
Fatal error.
no setter
isPending bool
Defines whether the state is final or some part of the synchronization process is still in progress.
no setter
isTemporaryError bool
Temporary error.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SyncState
no setter
syncCompletedDate DateTime?
Date of last successful full sync completion.
no setter
syncError SyncError?
no setter
syncFilesState SyncFilesState
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited